@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 extensions = [
     'sphinx.ext.todo',
     'sphinx.ext.intersphinx',
@@ -12,8 +10,8 @@ intersphinx_mapping = {
     'glib': ('https://lazka.github.io/pgi-docs/GLib-2.0', None),
     'gdk': ('https://lazka.github.io/pgi-docs/Gdk-3.0', None),
     'gio': ('https://lazka.github.io/pgi-docs/Gio-2.0', None),
-    'python2': ('https://docs.python.org/2.7', None),
-    'python3': ('https://docs.python.org/3', None),
+    'python': ('https://docs.python.org/3', None),
+    'cairo': ('https://pycairo.readthedocs.io/en/latest', None),
 }
 
 source_suffix = '.rst'
@@ -51,10 +49,10 @@ html_theme_options = {
 
 extlinks = {
     'bzbug': ('https://bugzilla.gnome.org/show_bug.cgi?id=%s', 'bz#'),
-    'issue': ('https://gitlab.gnome.org/GNOME/pygobject/issues/%s', 'issue#'),
-    'commit': ('https://gitlab.gnome.org/GNOME/pygobject/commit/%s', 'commit#'),
+    'issue': ('https://gitlab.gnome.org/GNOME/pygobject/issues/%s', '#'),
+    'commit': ('https://gitlab.gnome.org/GNOME/pygobject/commit/%s', ''),
     'mr': (
-        'https://gitlab.gnome.org/GNOME/pygobject/merge_requests/%s', 'mr#'),
+        'https://gitlab.gnome.org/GNOME/pygobject/merge_requests/%s', '!'),
     'user': ('https://gitlab.gnome.org/%s', ''),
 }
 
