@@ -23,7 +23,6 @@
  * IN THE SOFTWARE.
  */
 
-#include "pygi-python-compat.h"
 #include "pygi-info.h"
 #include "pygi-boxed.h"
 #include "pygi-type.h"
@@ -38,7 +37,7 @@ typedef struct
 } PyGRealSource;
 
 static gboolean
-pyg_source_prepare(GSource *source, gint *timeout)
+source_prepare(GSource *source, gint *timeout)
 {
     PyGRealSource *pysource = (PyGRealSource *)source;
     PyObject *t;
@@ -91,7 +90,7 @@ bail:
 }
 
 static gboolean
-pyg_source_check(GSource *source)
+source_check(GSource *source)
 {
     PyGRealSource *pysource = (PyGRealSource *)source;
     PyObject *t;
@@ -116,7 +115,7 @@ pyg_source_check(GSource *source)
 }
 
 static gboolean
-pyg_source_dispatch(GSource *source, GSourceFunc callback, gpointer user_data)
+source_dispatch(GSource *source, GSourceFunc callback, gpointer user_data)
 {
     PyGRealSource *pysource = (PyGRealSource *)source;
     PyObject *func, *args, *tuple, *t;
@@ -151,7 +150,7 @@ pyg_source_dispatch(GSource *source, GSourceFunc callback, gpointer user_data)
 }
 
 static void
-pyg_source_finalize(GSource *source)
+source_finalize(GSource *source)
 {
     PyGRealSource *pysource = (PyGRealSource *)source;
     PyObject *func, *t;
@@ -178,10 +177,10 @@ pyg_source_finalize(GSource *source)
 
 static GSourceFuncs pyg_source_funcs =
 {
-    pyg_source_prepare,
-    pyg_source_check,
-    pyg_source_dispatch,
-    pyg_source_finalize
+    source_prepare,
+    source_check,
+    source_dispatch,
+    source_finalize
 };
 
 /**
@@ -192,7 +191,7 @@ static GSourceFuncs pyg_source_funcs =
  * call Py_DECREF on the data.
  */
 static void
-_pyglib_destroy_notify(gpointer user_data)
+destroy_notify(gpointer user_data)
 {
     PyObject *obj = (PyObject *)user_data;
     PyGILState_STATE state;
@@ -203,7 +202,7 @@ _pyglib_destroy_notify(gpointer user_data)
 }
 
 static gboolean
-_pyglib_handler_marshal(gpointer user_data)
+handler_marshal(gpointer user_data)
 {
     PyObject *tuple, *ret;
     gboolean res;
@@ -230,7 +229,7 @@ _pyglib_handler_marshal(gpointer user_data)
 }
 
 PyObject *
-pyg_source_set_callback(PyGObject *self_module, PyObject *args)
+pygi_source_set_callback (PyGObject *self_module, PyObject *args)
 {
     PyObject *self, *first, *callback, *cbargs = NULL, *data;
     Py_ssize_t len;
@@ -268,30 +267,42 @@ pyg_source_set_callback(PyGObject *self_module, PyObject *args)
 	return NULL;
 
     g_source_set_callback(pyg_boxed_get (self, GSource),
-			  _pyglib_handler_marshal, data,
-			  _pyglib_destroy_notify);
+			  handler_marshal, data,
+			  destroy_notify);
 
     Py_INCREF(Py_None);
     return Py_None;
 }
 
 /**
- * pyg_source_new:
+ * pygi_source_new:
  *
  * Wrap the un-bindable g_source_new() and provide wrapper callbacks in the
  * GSourceFuncs which call back to Python.
+ *
+ * Returns NULL on error and sets an exception.
  */
 PyObject*
-pyg_source_new (void)
+pygi_source_new (PyObject *self, PyObject *args)
 {
-    PyGRealSource *source = NULL;
-    PyObject      *py_type;
+    PyGRealSource *source;
+    PyObject *py_type, *boxed;
 
-    source = (PyGRealSource*) g_source_new (&pyg_source_funcs, sizeof (PyGRealSource));
+    g_assert (args == NULL);
 
     py_type = pygi_type_import_by_name ("GLib", "Source");
+    if (!py_type)
+        return NULL;
+
+    source = (PyGRealSource*) g_source_new (&pyg_source_funcs, sizeof (PyGRealSource));
     /* g_source_new uses malloc, not slices */
-    source->obj = pygi_boxed_new ( (PyTypeObject *) py_type, source, FALSE, 0);
+    boxed = pygi_boxed_new ( (PyTypeObject *) py_type, source, TRUE, 0);
+    Py_DECREF (py_type);
+    if (!boxed) {
+        g_source_unref ((GSource *)source);
+        return NULL;
+    }
+    source->obj = boxed;
 
     return source->obj;
 }
